@@ -19,7 +19,6 @@ from qtpy.QtCore import QLineF, QPoint, QPointF, QRect, QRectF, QSize, QSizeF, Q
 from qtpy.QtGui import (
     QBrush,
     QPainter,
-    QPainterPath,
     QPen,
     QPixmap,
     QPolygonF,
@@ -342,7 +341,7 @@ class QwtSymbol_PrivateData(object):
         self.brush = br
         self.pen = pn
         self.isPinPointEnabled = False
-        self.pinPoint = QPointF()
+        self.pinPoint = None
 
         class Path(object):
             def __init__(self):
@@ -1236,7 +1235,7 @@ class QwtSymbol(object):
             :py:meth:`setCachePolicy()`, :py:meth:`drawSymbols()`
         """
         if self.__data.cache.pixmap is not None:
-            self.__data.cache.pixmap = QPixmap()
+            self.__data.cache.pixmap = None
 
     def setStyle(self, style):
         """
